% Solve the uncapacitated facility location problem using yalmip
% Andreas L. F. 2014
clc;
clear;
close all;
%% Set the number of clients m facilities n:
M = 5;      % Number of clients
N = 2;      % Number of facilities

%% Generate random profit coefficients, c(i,j) and facility setup cost d(j)
% Use randi to generate positive integers up to a maximum value iMax
iMax    = 100;
C       = randi(iMax,M,N);
D       = randi(iMax,N,1);

%% Define decision variables
y = binvar(N,1);
x = sdpvar(M,N,'full');

%% Define Objective
Objective = -sum(sum(C.*x)) + D'*y;

%% Define constraints
Satisfaction = (sum(x,2) == 1) + (x >= 0);
OpenFacilityForcing = (x <= repmat(y', M, 1));
Constraints = Satisfaction + OpenFacilityForcing;

%% Solve the optimization problem
options = sdpsettings('verbose', 1);
sol = optimize(Constraints, Objective, options);
if sol.problem == 0
 % Extract and display value
 facilities = value(y)
 clients = value(x)
 profit = -value(Objective)
else
 display('Hmm, something went wrong!');
 sol.info
 yalmiperror(sol.problem)
end